==> haskell-optparse-generic-1.3.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-generic
version: 1.3.0
id: optparse-generic-1.3.0-IGNzzTATwh7A78dBWGggz4
key: optparse-generic-1.3.0-IGNzzTATwh7A78dBWGggz4
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.
    .
    See the documentation in "Options.Generic" for an example of how to use
    this library
category: System
abi: 2765daa495bb56a942189aa0f172859f
exposed: True
exposed-modules:
    Options.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-generic-1.3.0
hs-libraries: HSoptparse-generic-1.3.0-IGNzzTATwh7A78dBWGggz4
depends:
    Only-0.1-4eYnxvcrr7tEbYgCvIkHLb base-4.12.0.0 bytestring-0.10.8.2
    optparse-applicative-0.14.3.0-93eSEj9ICWNLMTEZg8268q
    system-filepath-0.4.14-FRUtJu5zAWTG9MKrRBz8D6 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock
haddock-html: /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-generic-1.3.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-generic
version: 1.3.0
id: optparse-generic-1.3.0-9CE1dcSZQlXLnlf4w7wcfF
key: optparse-generic-1.3.0-9CE1dcSZQlXLnlf4w7wcfF
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.
    .
    See the documentation in "Options.Generic" for an example of how to use
    this library
category: System
abi: bb24433a55cc0d35822147b3c4a2bb69
exposed: True
exposed-modules:
    Options.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-generic-1.3.0
hs-libraries: HSoptparse-generic-1.3.0-9CE1dcSZQlXLnlf4w7wcfF
depends:
    Only-0.1-4eYnxvcrr7tEbYgCvIkHLb base-4.12.0.0 bytestring-0.10.8.2
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    system-filepath-0.4.14-F6tWnQ8w6Re4FOKikOPtM5 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock
haddock-html: /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
